@@ -36,10 +36,10 @@ class SyncronizeScribusDocument01TestCase(unittest.TestCase):
     def testSimplePageobjects(self):
         """ Test if simple pageobjects are in the output """
 
-        first_node = self.outputtree.xpath("count(//PAGEOBJECT[@ANNAME='id002'])")
+        first_node = self.outputtree.xpath("count(//PAGEOBJECT[@ANNAME='id001'])")
         self.assertEqual(first_node, 1.0)
 
-        second_node = self.outputtree.xpath("count(//PAGEOBJECT[@ANNAME='id003'])")
+        second_node = self.outputtree.xpath("count(//PAGEOBJECT[@ANNAME='id002'])")
         self.assertEqual(second_node, 1.0)
 
         third_node = self.outputtree.xpath("count(//PAGEOBJECT[@ANNAME='id004'])")
@@ -47,27 +47,27 @@ class SyncronizeScribusDocument01TestCase(unittest.TestCase):
 
     def testSimplePageobjectsContent(self):
         """ Test if simple pageobjects contain the correct content """
-        content002 = self.outputtree.xpath("//PAGEOBJECT[@ANNAME='id002']/ITEXT/@CH")
-        self.assertEqual(content002, ['Article 1 Title'])
+        content002 = self.outputtree.xpath("//PAGEOBJECT[@ANNAME='id001']/ITEXT/@CH")
+        self.assertEqual(content002, ['Article 1 DocBook Title'])
 
-        content003 = self.outputtree.xpath("//PAGEOBJECT[@ANNAME='id003']/ITEXT/@CH")
-        self.assertEqual(content003, ['Article 1 Subtitle'])
+        content003 = self.outputtree.xpath("//PAGEOBJECT[@ANNAME='id002']/ITEXT/@CH")
+        self.assertEqual(content003, ['Article 1 DocBook Subtitle'])
 
         content004 = self.outputtree.xpath("//PAGEOBJECT[@ANNAME='id004']/ITEXT/@CH")
-        self.assertEqual(content004, ['Article 1 First Blockquote'])
+        self.assertEqual(content004, ['Article 1 DocBook First Blockquote'])
 
 
     def testComplexPageobjects(self):
         """ Test if complex pageobjects are in the output """
 
-        third_node = self.outputtree.xpath("count(//PAGEOBJECT[@ANNAME='id001'])")
+        third_node = self.outputtree.xpath("count(//PAGEOBJECT[@ANNAME='id003'])")
         self.assertEqual(third_node, 1.0)
 
     def testComplexPageobjectsContent(self):
         """ Test if complex pageobjects contain the correct content """
 
-        content001 = self.outputtree.xpath("//PAGEOBJECT[@ANNAME='id001']/ITEXT/@CH")
-        self.assertEqual(content001, ['Article 1 First Para.', 'Article 1 First Subheadline', 'Article 1 Second Para', 'Article 1 Third Para', 'Article 1 Fourth Para', 'Article 1 Second Subheadline', 'Article 1 Sixt Para', 'Article 1 Seventh Para'])
+        content001 = self.outputtree.xpath("//PAGEOBJECT[@ANNAME='id003']/ITEXT/@CH")
+        self.assertEqual(content001, ['Article 1 DocBook First Para.', 'Article 1 DocBook First Subheadline', 'Article 1 DocBook Second Para', 'Article 1 DocBook Third Para', 'Article 1 DocBook Fourth Para', 'Article 1 DocBook Second Subheadline', 'Article 1 DocBook Sixt Para', 'Article 1 DocBook Seventh Para'])
 
 class SyncronizeScribusDocument02TestCase(unittest.TestCase):
 
@@ -94,10 +94,10 @@ class SyncronizeScribusDocument02TestCase(unittest.TestCase):
     def testSimplePageobjects(self):
         """ Test if simple pageobjects are in the output """
 
-        first_node = self.outputtree.xpath("count(//PAGEOBJECT[@ANNAME='id002'])")
+        first_node = self.outputtree.xpath("count(//PAGEOBJECT[@ANNAME='id001'])")
         self.assertEqual(first_node, 1.0)
 
-        second_node = self.outputtree.xpath("count(//PAGEOBJECT[@ANNAME='id003'])")
+        second_node = self.outputtree.xpath("count(//PAGEOBJECT[@ANNAME='id002'])")
         self.assertEqual(second_node, 1.0)
 
         third_node = self.outputtree.xpath("count(//PAGEOBJECT[@ANNAME='id004'])")
@@ -105,27 +105,27 @@ class SyncronizeScribusDocument02TestCase(unittest.TestCase):
 
     def testSimplePageobjectsContent(self):
         """ Test if simple pageobjects contain the correct content """
-        content002 = self.outputtree.xpath("//PAGEOBJECT[@ANNAME='id002']/ITEXT/@CH")
-        self.assertEqual(content002, ['Article 1 Title'])
+        content001 = self.outputtree.xpath("//PAGEOBJECT[@ANNAME='id001']/ITEXT/@CH")
+        self.assertEqual(content001, ['Article 1 DocBook Title'])
 
-        content003 = self.outputtree.xpath("//PAGEOBJECT[@ANNAME='id003']/ITEXT/@CH")
-        self.assertEqual(content003, ['Article 1 Subtitle'])
+        content002 = self.outputtree.xpath("//PAGEOBJECT[@ANNAME='id002']/ITEXT/@CH")
+        self.assertEqual(content002, ['Article 1 DocBook Subtitle'])
 
         content004 = self.outputtree.xpath("//PAGEOBJECT[@ANNAME='id004']/ITEXT/@CH")
-        self.assertEqual(content004, ['Article 1 First Blockquote'])
+        self.assertEqual(content004, ['Article 1 DocBook First Blockquote'])
 
 
     def testComplexPageobjects(self):
         """ Test if complex pageobjects are in the output """
 
-        third_node = self.outputtree.xpath("count(//PAGEOBJECT[@ANNAME='id001'])")
+        third_node = self.outputtree.xpath("count(//PAGEOBJECT[@ANNAME='id003'])")
         self.assertEqual(third_node, 1.0)
 
     def testComplexPageobjectsContent(self):
         """ Test if complex pageobjects contain the correct content """
 
-        content001 = self.outputtree.xpath("//PAGEOBJECT[@ANNAME='id001']/ITEXT/@CH")
-        self.assertEqual(content001, ['Article 1 First Para.', 'Article 1 First Subheadline', 'Article 1 Second Para', 'Article 1 Third Para', 'Article 1 Fourth Para', 'Article 1 Second Subheadline', 'Article 1 Sixt Para', 'Article 1 Seventh Para'])
+        content003 = self.outputtree.xpath("//PAGEOBJECT[@ANNAME='id003']/ITEXT/@CH")
+        self.assertEqual(content003, ['Article 1 DocBook First Para.', 'Article 1 DocBook First Subheadline', 'Article 1 DocBook Second Para', 'Article 1 DocBook Third Para', 'Article 1 DocBook Fourth Para', 'Article 1 DocBook Second Subheadline', 'Article 1 DocBook Sixt Para', 'Article 1 DocBook Seventh Para'])
 
 class RejectInvalidInputTestCase(unittest.TestCase):
 
@@ -168,7 +168,10 @@ class SyncronizeWithAdditionalScribusPageobjectsTestCase(unittest.TestCase):
 
 def test_suite():
 
-    suite = unittest.TestLoader().loadTestsFromTestCase(SyncronizeScribusDocumentTestCase)
+    suite = unittest.TestLoader().loadTestsFromTestCase(SyncronizeScribusDocument01TestCase)
+    unittest.TextTestRunner(verbosity=2).run(suite)
+
+    suite = unittest.TestLoader().loadTestsFromTestCase(SyncronizeScribusDocument02TestCase)
     unittest.TextTestRunner(verbosity=2).run(suite)
 
     suite = unittest.TestLoader().loadTestsFromTestCase(RejectInvalidInputTestCase)
